@@ -47,7 +47,7 @@ log = logging.getLogger(__name__)
 @task(notifications_disabled=True)
 def import_tool(**kw):
     importer = GoogleCodeWikiImporter()
-    with ImportErrorHandler(importer, kw.get('project_name')):
+    with ImportErrorHandler(importer, kw.get('project_name'), c.project):
         importer.import_tool(c.project, c.user, **kw)
 
 
@@ -74,13 +74,16 @@ class GoogleCodeWikiImportController(BaseController):
     @require_post()
     @validate(GoogleCodeWikiImportForm(ForgeWikiApp), error_handler=index)
     def create(self, gc_project_name, mount_point, mount_label, **kw):
-        import_tool.post(
-                project_name=gc_project_name,
-                mount_point=mount_point,
-                mount_label=mount_label,
-                )
-        flash('Wiki import has begun. Your new wiki will be available '
-                'when the import is complete.')
+        if GoogleCodeWikiImporter().enforce_limit(c.project):
+            import_tool.post(
+                    project_name=gc_project_name,
+                    mount_point=mount_point,
+                    mount_label=mount_label,
+                    )
+            flash('Wiki import has begun. Your new wiki will be available '
+                    'when the import is complete.')
+        else:
+            flash('There are too many imports pending at this time.  Please wait and try again.', 'error')
         redirect(c.project.url() + 'admin/')
 
 
