@@ -1,8 +1,10 @@
 from unittest import TestCase
 from mock import Mock, patch
+from ming.odm import ThreadLocalORMSession
 
 from allura.tests import TestController
 from allura.tests.decorators import with_wiki
+from allura import model as M
 
 from googlecodewikiimporter.importer import (
         GoogleCodeWikiImporter,
@@ -267,6 +269,21 @@ class TestGoogleCodeWikiImportController(TestController, TestCase):
         self.assertEqual(u'mylabel', import_tool.post.call_args[1]['mount_label'])
         self.assertEqual(u'myproject', import_tool.post.call_args[1]['project_name'])
 
+    @with_wiki
+    @patch('googlecodewikiimporter.importer.import_tool')
+    def test_create_limit(self, import_tool):
+        project = M.Project.query.get(shortname='test')
+        project.set_tool_data('GoogleCodeWikiImporter', pending=1)
+        ThreadLocalORMSession.flush_all()
+        params = dict(gc_project_name='myproject',
+                mount_label='mylabel',
+                mount_point='mymount',
+                )
+        r = self.app.post('/p/test/admin/wiki/_importer/create', params,
+                status=302).follow()
+        self.assertIn('Please wait and try again', r)
+        self.assertEqual(import_tool.post.call_count, 0)
+
 
 class TestGoogleCodeWikiExtractor(TestCase):
 
